![test](https://github.com/davips/hoshmap/workflows/test/badge.svg)
[![codecov](https://codecov.io/gh/davips/hoshmap/branch/main/graph/badge.svg)](https://codecov.io/gh/davips/hoshmap)
<a href="https://pypi.org/project/hoshmap">
<img src="https://img.shields.io/pypi/v/hoshmap.svg?label=release&color=blue&style=flat-square" alt="pypi">
</a>
![Python version](https://img.shields.io/badge/python-3.8%20%7C%203.9-blue.svg)
[![license: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)

<!--- [![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.5501845.svg)](https://doi.org/10.5281/zenodo.5501845) --->
[![arXiv](https://img.shields.io/badge/arXiv-2109.06028-b31b1b.svg?style=flat-square)](https://arxiv.org/abs/2109.06028)
[![API documentation](https://img.shields.io/badge/doc-API%20%28auto%29-a0a0a0.svg)](https://davips.github.io/hoshmap)

# hoshmap
A cacheable lazy dict with universally unique deterministic identifiers and transparent agnostic persistence.

## This library is the successor of the package [idict](https://pypi.org/project/idict)
Most of the _idict_ documentation still applies to _hoshmap_'s _idict_.
